==> redpesk-cli_3.15.0.orig.tar.gz: redpesk-cli-3.15.0/rpladmock/mock_constants.go <==
/*
Copyright © 2020-2023 IoT.bzh Company
Contact: https://www.iot.bzh/licensing

This file is part of the redpesk-cli project, the redpesk command line tool.

$RP_BEGIN_LICENSE$
Commercial License Usage
 Licensees holding valid commercial IoT.bzh licenses may use this file in
 accordance with the commercial license agreement provided with the
 Software or, alternatively, in accordance with the terms contained in
 a written agreement between you and The IoT.bzh Company. For licensing terms
 and conditions see https://www.iot.bzh/terms-conditions. For further
 information use the contact form at https://www.iot.bzh/contact.

GNU General Public License Usage
 Alternatively, this file may be used under the terms of the GNU General
 Public license version 3. This license is as published by the Free Software
 Foundation and appearing in the file LICENSE.GPLv3 included in the packaging
 of this file. Please review the following information to ensure the GNU
 General Public License requirements will be met
 https://www.gnu.org/licenses/gpl-3.0.html.
$RP_END_LICENSE$
*/

package rpladmock

const (
	mockHeader       = "=====> MOCKED LAD <====="
	serverAddress    = ":8112"
	mockedAPIVersion = "1"
	apiRouteHeader   = "/api/v" + mockedAPIVersion + "/"
	wSocketRoute     = "/socket.io/"

	gitSourcesTestDir  = "/tmp/redpesk-cli-test/gitsources"
	gitPackagesTestDir = "/tmp/redpesk-cli-test/gitpkgs"

	// --------------------------------------------------------------
	// Version route and handler ------------------------------------
	// --------------------------------------------------------------
	versionRoute = apiRouteHeader + "version"
	// --------------------------------------------------------------
	// --------------------------------------------------------------

	// --------------------------------------------------------------
	// Events route and handler -------------------------------------
	// --------------------------------------------------------------
	eventRoute            = apiRouteHeader + "event"
	eventSubscribeRoute   = eventRoute + "/subscribe"
	eventUnsubscribeRoute = eventRoute + "/unsubscribe"
	eventListRoute        = eventRoute + "/list"
	// --------------------------------------------------------------
	// --------------------------------------------------------------

	// --------------------------------------------------------------
	// Iotpkg route and handler -------------------------------------
	// --------------------------------------------------------------
	iotpkgRoute                = apiRouteHeader + "iotpkg"
	iotpkgLocalbuildRoute      = iotpkgRoute + "/localbuild"
	iotpkgLocalcrossbuildRoute = iotpkgRoute + "/localcrossbuild"
	iotpkgArchiveRoute         = iotpkgRoute + "/archive"
	// --------------------------------------------------------------
	// --------------------------------------------------------------

	// --------------------------------------------------------------
	// Exec route and handler ---------------------------------------
	// --------------------------------------------------------------
	execRoute = apiRouteHeader + "exec"
	// --------------------------------------------------------------
	// --------------------------------------------------------------

	// --------------------------------------------------------------
	// Terminal route and handler -----------------------------------
	// --------------------------------------------------------------
	terminalRoute       = apiRouteHeader + "terminal"
	terminalSizeRoute   = terminalRoute + "/size"
	terminalSignalRoute = terminalRoute + "/signal"
	// --------------------------------------------------------------
	// --------------------------------------------------------------

	// --------------------------------------------------------------
	// Symlink route and handler ------------------------------------
	// --------------------------------------------------------------
	symlinkRoute = apiRouteHeader + "symlink"
	// --------------------------------------------------------------
	// --------------------------------------------------------------

	// --------------------------------------------------------------
	// Debug messages -----------------------------------------------
	// --------------------------------------------------------------
	wsConnectionMsg    = mockHeader + " Connection on websocket server"
	wsDisconnectionMsg = mockHeader + " Disconnection on websocket server"
	// --------------------------------------------------------------
	// --------------------------------------------------------------

	// --------------------------------------------------------------
	// Error messages -----------------------------------------------
	// --------------------------------------------------------------
	exitServerRunErr  = mockHeader + " Exit with error: %v"
	shutdownServerErr = mockHeader + " An error occurred while shutting down the mocked server: %v"
	wsErrorErr        = mockHeader + " Error on the websocket: %v"
	// --------------------------------------------------------------
	// --------------------------------------------------------------
)

==> redpesk-cli_3.18.0.orig.tar.gz: redpesk-cli-3.18.0/rpladmock/mock_constants.go <==
/*
Copyright © 2020-2023 IoT.bzh Company
Contact: https://www.iot.bzh/licensing

This file is part of the redpesk-cli project, the redpesk command line tool.

$RP_BEGIN_LICENSE$
Commercial License Usage
 Licensees holding valid commercial IoT.bzh licenses may use this file in
 accordance with the commercial license agreement provided with the
 Software or, alternatively, in accordance with the terms contained in
 a written agreement between you and The IoT.bzh Company. For licensing terms
 and conditions see https://www.iot.bzh/terms-conditions. For further
 information use the contact form at https://www.iot.bzh/contact.

GNU General Public License Usage
 Alternatively, this file may be used under the terms of the GNU General
 Public license version 3. This license is as published by the Free Software
 Foundation and appearing in the file LICENSE.GPLv3 included in the packaging
 of this file. Please review the following information to ensure the GNU
 General Public License requirements will be met
 https://www.gnu.org/licenses/gpl-3.0.html.
$RP_END_LICENSE$
*/

package rpladmock

const (
	mockHeader       = "=====> MOCKED LAD <====="
	serverAddress    = ":8112"
	mockedAPIVersion = "1"
	apiRouteHeader   = "/api/v" + mockedAPIVersion + "/"
	wSocketRoute     = "/socket.io/"

	gitSourcesTestDir  = "/tmp/redpesk-cli-test/gitsources"
	gitPackagesTestDir = "/tmp/redpesk-cli-test/gitpkgs"

	// --------------------------------------------------------------
	// Version route and handler ------------------------------------
	// --------------------------------------------------------------
	versionRoute = apiRouteHeader + "version"
	// --------------------------------------------------------------
	// --------------------------------------------------------------

	// --------------------------------------------------------------
	// Events route and handler -------------------------------------
	// --------------------------------------------------------------
	eventRoute            = apiRouteHeader + "event"
	eventSubscribeRoute   = eventRoute + "/subscribe"
	eventUnsubscribeRoute = eventRoute + "/unsubscribe"
	eventListRoute        = eventRoute + "/list"
	// --------------------------------------------------------------
	// --------------------------------------------------------------

	// --------------------------------------------------------------
	// Iotpkg route and handler -------------------------------------
	// --------------------------------------------------------------
	iotpkgRoute                = apiRouteHeader + "iotpkg"
	iotpkgLocalbuildRoute      = iotpkgRoute + "/localbuild"
	iotpkgLocalcrossbuildRoute = iotpkgRoute + "/localcrossbuild"
	iotpkgArchiveRoute         = iotpkgRoute + "/archive"
	iotpkgRPBuildRoute         = iotpkgRoute + "/rpbuild"
	iotpkgMetadataRoute        = iotpkgRoute + "/metadata"
	iotpkgServiceRoute         = iotpkgRoute + "/service"
	iotpkgInitRoute            = iotpkgRoute + "/init"
	iotpkgCleanMockRoute       = iotpkgRoute + "/cleanmock"
	// --------------------------------------------------------------
	// --------------------------------------------------------------

	// --------------------------------------------------------------
	// Exec route and handler ---------------------------------------
	// --------------------------------------------------------------
	execRoute = apiRouteHeader + "exec"
	// --------------------------------------------------------------
	// --------------------------------------------------------------

	// --------------------------------------------------------------
	// Symlink route and handler ------------------------------------
	// --------------------------------------------------------------
	symlinkRoute = apiRouteHeader + "symlink"
	// --------------------------------------------------------------
	// --------------------------------------------------------------

	// --------------------------------------------------------------
	// Iotpkg cfg file content --------------------------------------
	// --------------------------------------------------------------
	iotpkgFileContent = `# Auto-generated by the Koji build system

config_opts['basedir'] = '/var/lib/mock'
config_opts['chroot_setup_cmd'] = 'groupinstall build'
config_opts['chroothome'] = '/builddir'
config_opts['dnf_warning'] = False
config_opts['root'] = 'simple-project_b437d650--redpesk-lts-batz-2.0-update-build-redpesk-lts-batz-2.0-update-aarch64-cross'
[..]
`
	// --------------------------------------------------------------
	// --------------------------------------------------------------

	// --------------------------------------------------------------
	// Debug messages -----------------------------------------------
	// --------------------------------------------------------------
	wsConnectionMsg    = mockHeader + " Connection on websocket server"
	wsDisconnectionMsg = mockHeader + " Disconnection on websocket server"
	// --------------------------------------------------------------
	// --------------------------------------------------------------

	// --------------------------------------------------------------
	// Error messages -----------------------------------------------
	// --------------------------------------------------------------
	exitServerRunErr  = mockHeader + " Exit with error: %v"
	shutdownServerErr = mockHeader + " An error occurred while shutting down the mocked server: %v"
	wsErrorErr        = mockHeader + " Error on the websocket: %v"
	// --------------------------------------------------------------
	// --------------------------------------------------------------
)
